__description__ = 'crystalflow, XRD Enhanced Crystal Graph Dataloader'
__author__ = 'Bin Cao, Advanced Materials Thrust, Hong Kong University of Science and Technology (Guangzhou)'
__author_email__ = 'binjacobcao@gmail.com'
__url__ = 'https://github.com/Bin-Cao/CrystalFlow'